@@ -1,6 +1,6 @@
 use clap::{Command, Arg};
 
-const VERSION: &'static str = "0.3.0";
+const VERSION: &'static str = "0.3.1";
 
 pub fn build_cli() -> Command<'static> {
     Command::new("pouf")
@@ -8,6 +8,7 @@ pub fn build_cli() -> Command<'static> {
     .version(VERSION)
     .author("Ferry Jérémie ferryjeremie@free.fr")
     .about("give fake datas")
+    .arg_required_else_help(true)
     .subcommand(
         Command::new("lorem.word")
         .about("give a fake word")
@@ -48,6 +49,9 @@ pub fn build_cli() -> Command<'static> {
     .subcommand(Command::new("internet.useragent")
         .about("give a fake user agent")
     )
+    .subcommand(Command::new("internet.color")
+        .about("give a fake hexadecimal color")
+    )
     .subcommand(Command::new("http.code")
         .about("give a fake HTTP code")
     )
@@ -79,4 +83,7 @@ pub fn build_cli() -> Command<'static> {
     .subcommand(Command::new("finance.bic")
         .about("give a fake BIC (Business Identifier Code)")
     )
+    .subcommand(Command::new("auto.licenseplate")
+        .about("give a french automotive license plate")
+    )
 }
